@@ -11,7 +11,7 @@ namespace
     ArgConfig::LongOption lo[] =
     {
         ArgConfig::LongOption("option", 'o'),
-        ArgConfig::LongOption("value-option", 'v')
+        ArgConfig::LongOption("option-value", 'v')
     };
 }
 
@@ -65,6 +65,6 @@ try
 }
 catch (Errno const &err)
 {
-    cout << "Terminating " << err.what() << endl;
+    cout << "Terminating " << err.why() << endl;
     return 1;
 }
