@@ -5,20 +5,20 @@ using namespace std;
 
 bool DateTime::setMonth(Month month, Relative where)
 {
-    struct tm tmStruct = d_tm;
+    TimeStruct ts = d_tm;
 
     switch (where)
     {
         case NEXT:
                         // For NEXT: At Sep, specify May: next year
             if (static_cast<int>(month) < d_tm.tm_mon)
-                ++tmStruct.tm_year;
+                ++ts.tm_year;
         break;
 
         case LAST:
                         // For LAST: At Sep, specify Oct: previous year
             if (static_cast<int>(month) > d_tm.tm_mon)
-                --tmStruct.tm_year;
+                --ts.tm_year;
         break;
 
         case THIS_YEAR:
@@ -28,9 +28,9 @@ bool DateTime::setMonth(Month month, Relative where)
         throw Errno(1, "DateTime::setMonth(): invalid Relative spec.");
     }
 
-    tmStruct.tm_mon = month;
+    ts.tm_mon = month;
 
-    return updateTime(&tmStruct);
+    return updateTime(ts);
 }
 
 
